@@ -1,6 +1,7 @@
 # -*- coding: spec -*-
 # This is a comparison of DSL syntax to what is generated
 
+import six
 import nose
 import nose.tools
 from sure import expect, this
@@ -13,6 +14,23 @@ import nose
 import pkg_resources
 import python_jsonschema_objects as pjs
 
+describe TestCase, 'regression #9':
+
+    it 'should not throw an error':
+        import python_jsonschema_objects
+        schema = {
+                "$schema": "http://json-schema.org/schema#",
+                "id": "test",
+                "type": "object",
+                "properties": {
+                    "name": {"type": "string"},
+                    "email": {"oneOf": [ "string", "integer"]},
+                    },
+                "required": ["email"]
+                }
+        builder = python_jsonschema_objects.ObjectBuilder(schema)
+        builder.build_classes()
+
 describe TestCase, 'markdown extraction':
 
     before_each:
@@ -36,7 +54,7 @@ describe TestCase, 'markdown extraction':
             builder.validate.when.called_with({'MyAddress': '1234'}).should_not.throw(pjs.ValidationError)
 
         it 'should be able to read an object':
-            for nm, ex in self.examples.iteritems():
+            for nm, ex in six.iteritems(self.examples):
                 builder = pjs.ObjectBuilder(ex, resolved=self.examples)
                 builder.should.be.ok
 
